<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>AppItemMenu</name>
    <message>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <source>Pin to Top</source>
        <translation>Przypnij na górze</translation>
    </message>
    <message>
        <source>Move to Top</source>
        <translation>Przenieś na górę</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Usuń z ulubionych</translation>
    </message>
    <message>
        <source>Add to favorites</source>
        <translation>Dodaj do ulubionych</translation>
    </message>
    <message>
        <source>Remove from desktop</source>
        <translation>Usuń z pulpitu</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Wyślij na pulpit</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Usuń z doku</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Dodaj do doku</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Usuń z startu systemu</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Dodaj do startu systemu</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation>Użyj proxy</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Wyłącz skalowanie ekranu</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Odinstaluj</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <source>Power</source>
        <translation>Zasilanie</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <source>Full-screen Mode</source>
        <translation>Tryb pełnoekranowy</translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <source>Install</source>
        <translation>Zainstaluj</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <source>Frequently Used</source>
        <translation>Często używane</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Window Mode</source>
        <translation>Tryb okna</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Rozmowy</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzyka</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Wideo</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafika</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Gry</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Biuro</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Czytanie</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Programowanie</translation>
    </message>
    <message>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Inne</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation>Czy na pewno odinstalować &quot;%1&quot;?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potwierdź</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <source>Recently Installed</source>
        <translation>Ostatnio zainstalowane</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <source>All Apps</source>
        <translation>Wszystkie aplikacje</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Brak wyników wyszukiwania</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <source>Free sorting</source>
        <translation>Swobodne sortowanie</translation>
    </message>
    <message>
        <source>Sort by category</source>
        <translation>Sortuj wg. kategorii</translation>
    </message>
    <message>
        <source>Sort by name</source>
        <translation>Sortuj wg. nazwy</translation>
    </message>
    <message>
        <source>Sorting Mode</source>
        <translation>Tryb sortowania</translation>
    </message>
    <message>
        <source>Computer</source>
        <translation>Komputer</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Zdjęcia</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Pulpit</translation>
    </message>
    <message>
        <source>Control Center</source>
        <translation>Centrum kontroli</translation>
    </message>
</context>
<context>
    <name>launcheritem</name>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Komunikacja</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzyka</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Wideo</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafika</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Gry</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Biurowe</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Czytanie</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Programowanie</translation>
    </message>
    <message>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Inne</translation>
    </message>
    <message>
        <source>launchpad</source>
        <translation>Launchpad</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation>Czy na pewno odinstalować &quot;%1&quot;?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potwierdź</translation>
    </message>
</context>
</TS>